@@ -77,7 +77,7 @@ tbr_gmean <- function(.tbl, x, tcolumn, unit = "years", n, ...) {
 #' @param ... additional arguments passed to gmean_ci
 #'
 #' @importFrom lubridate as.duration duration
-#' @importFrom tibble as.tibble
+#' @importFrom tibble as_tibble
 #' @return list
 #' @keywords internal
 tbr_gmean_window <- function(x, tcolumn, unit = "years", n, i, ...) {
@@ -109,7 +109,7 @@ tbr_gmean_window <- function(x, tcolumn, unit = "years", n, i, ...) {
   else {
     # create a time-based window by calculating the duration between current row
     # and the previous rows select the rows where 0 <= duration <= n
-    window <- x[lubridate::as.duration(tcolumn[i] - tcolumn)/lubridate::duration(num = 1, units = unit) <= n & lubridate::as.duration(tcolumn[i] - tcolumn)/lubridate::duration(num = 1, units = unit) >= 0]
+    window <- open_window(x, tcolumn, unit = unit, n, i)
 
     # if length is 1 or less, return NAs
     if (length(window) <= 1) {
@@ -122,7 +122,7 @@ tbr_gmean_window <- function(x, tcolumn, unit = "years", n, i, ...) {
     else{
 
       if (is.na(dots$conf)) {
-        results <- tibble::as.tibble(list(mean = gm_mean_ci(window = window, ...)))
+        results <- tibble::as_tibble(list(mean = gm_mean_ci(window = window, ...)))
       }
 
       else {
@@ -146,7 +146,7 @@ tbr_gmean_window <- function(x, tcolumn, unit = "years", n, i, ...) {
 #' https://stackoverflow.com/questions/2602583/geometric-mean-is-there-a-built-in
 #' @param x vector of numeric values
 #' @param na.rm logical TRUE/FALSE remove NA values
-#' @param zero.propagate logical TRUE/FALSE. Allows the optional propogation of
+#' @param zero.propagate logical TRUE/FALSE. Allows the optional propagation of
 #'   zeros.
 #'
 #' @return the geometric mean of the vector
