@@ -91,7 +91,7 @@ tbr_median_window <- function(x, tcolumn, unit = "years", n, i, ...) {
   else {
     # create a time-based window by calculating the duration between current row
     # and the previous rows select the rows where 0 <= duration <= n
-    window <- x[lubridate::as.duration(tcolumn[i] - tcolumn)/lubridate::duration(num = 1, units = unit) <= n & lubridate::as.duration(tcolumn[i] - tcolumn)/lubridate::duration(num = 1, units = unit) >= 0]
+    window <- open_window(x, tcolumn, unit = unit, n, i)
 
     # if length is 1 or less, return NAs
     if (length(window) <= 1) {
